@@ -216,10 +216,9 @@ void NetworkSlave::listDir( const QUrl& url )
 //qDebug()<<reply.isValid();
             if( reply.isValid() ) // TODO: find how a not found service can be expressed in the reply
             {
-                Mollet::NetDeviceList deviceDataList = reply.value();
+                const Mollet::NetDeviceList deviceDataList = reply.value();
 
-                foreach( const Mollet::NetDevice& deviceData, deviceDataList )
-                {
+                for (const Mollet::NetDevice& deviceData : deviceDataList) {
                     KIO::UDSEntry entry;
                     feedEntryAsDevice( &entry, deviceData );
                     listEntry( entry );
@@ -238,10 +237,9 @@ void NetworkSlave::listDir( const QUrl& url )
 //qDebug()<<reply.isValid();
                 if( reply.isValid() ) // TODO: find how a not found service can be expressed in the reply
                 {
-                    Mollet::NetServiceList serviceDataList = reply.value();
+                    const Mollet::NetServiceList serviceDataList = reply.value();
 
-                    foreach( const Mollet::NetService& serviceData, serviceDataList )
-                    {
+                    for (const Mollet::NetService& serviceData : serviceDataList) {
                         KIO::UDSEntry entry;
                         feedEntryAsService( &entry, serviceData );
                         listEntry( entry );
@@ -279,32 +277,32 @@ void NetworkSlave::listDir( const QUrl& url )
 
 void NetworkSlave::feedEntryAsNetwork( KIO::UDSEntry* entry )
 {
-    entry->insert( KIO::UDSEntry::UDS_FILE_TYPE,    S_IFDIR );
-//     entry->insert( KIO::UDSEntry::UDS_ICON_NAME,    NetworkIconName );
-    entry->insert( KIO::UDSEntry::UDS_MIME_TYPE,    QLatin1String(Mimetypes::NetworkMimetype) );
+    entry->fastInsert( KIO::UDSEntry::UDS_FILE_TYPE,    S_IFDIR );
+//     entry->fastInsert( KIO::UDSEntry::UDS_ICON_NAME,    NetworkIconName );
+    entry->fastInsert( KIO::UDSEntry::UDS_MIME_TYPE,    QLatin1String(Mimetypes::NetworkMimetype) );
 
 }
 
 void NetworkSlave::feedEntryAsDevice( KIO::UDSEntry* entry, const Mollet::NetDevice& deviceData )
 {
-    entry->insert( KIO::UDSEntry::UDS_NAME,         deviceData.hostAddress() );
-    entry->insert( KIO::UDSEntry::UDS_DISPLAY_NAME, deviceData.name() );
-    entry->insert( KIO::UDSEntry::UDS_FILE_TYPE,    S_IFDIR );
-//     entry->insert( KIO::UDSEntry::UDS_ICON_NAME,    NetDevice::iconName(deviceData.type()) );
-    entry->insert( KIO::UDSEntry::UDS_MIME_TYPE,    QLatin1String(Mimetypes::DeviceMimetype[deviceData.type()]) );
+    entry->fastInsert( KIO::UDSEntry::UDS_NAME,         deviceData.hostAddress() );
+    entry->fastInsert( KIO::UDSEntry::UDS_DISPLAY_NAME, deviceData.name() );
+    entry->fastInsert( KIO::UDSEntry::UDS_FILE_TYPE,    S_IFDIR );
+//     entry->fastInsert( KIO::UDSEntry::UDS_ICON_NAME,    NetDevice::iconName(deviceData.type()) );
+    entry->fastInsert( KIO::UDSEntry::UDS_MIME_TYPE,    QLatin1String(Mimetypes::DeviceMimetype[deviceData.type()]) );
 
 }
 
 void NetworkSlave::feedEntryAsService( KIO::UDSEntry* entry, const Mollet::NetService& serviceData )
 {
-    entry->insert( KIO::UDSEntry::UDS_NAME,         serviceData.name()+QLatin1Char('.')+serviceData.type() );
-    entry->insert( KIO::UDSEntry::UDS_DISPLAY_NAME, serviceData.name() );
-    entry->insert( KIO::UDSEntry::UDS_FILE_TYPE,    S_IFLNK );
-    entry->insert( KIO::UDSEntry::UDS_ACCESS,       S_IRWXU|S_IRWXG|S_IRWXO );
-    entry->insert( KIO::UDSEntry::UDS_ICON_NAME,    serviceData.iconName() );
-    entry->insert( KIO::UDSEntry::UDS_MIME_TYPE,    Mimetypes::mimetypeForServiceType(serviceData.type()) );
+    entry->fastInsert( KIO::UDSEntry::UDS_NAME,         serviceData.name()+QLatin1Char('.')+serviceData.type() );
+    entry->fastInsert( KIO::UDSEntry::UDS_DISPLAY_NAME, serviceData.name() );
+    entry->fastInsert( KIO::UDSEntry::UDS_FILE_TYPE,    S_IFLNK );
+    entry->fastInsert( KIO::UDSEntry::UDS_ACCESS,       S_IRWXU|S_IRWXG|S_IRWXO );
+    entry->fastInsert( KIO::UDSEntry::UDS_ICON_NAME,    serviceData.iconName() );
+    entry->fastInsert( KIO::UDSEntry::UDS_MIME_TYPE,    Mimetypes::mimetypeForServiceType(serviceData.type()) );
     if( !serviceData.url().isEmpty() )
-        entry->insert( KIO::UDSEntry::UDS_TARGET_URL, serviceData.url() );
+        entry->fastInsert( KIO::UDSEntry::UDS_TARGET_URL, serviceData.url() );
 }
 
 void NetworkSlave::reportError( const NetworkUri& networkUri, int errorId )
