@@ -33,7 +33,7 @@
 #include <QFile>
 #include <QDir>
 #include <QDebug>
-#include <QtNetwork/QHostInfo>
+#include <QHostInfo>
 
 #include <KLocalizedString>
 #include <kio/global.h>
@@ -553,7 +553,7 @@ NFSFileHandle NFSProtocol::getFileHandle(const QString& path)
         return NFSFileHandle();
     }
 
-    // Look up the file handle from the procotol
+    // Look up the file handle from the protocol
     NFSFileHandle childFH = lookupFileHandle(path);
     if (!childFH.isInvalid()) {
         m_handleCache.insert(path, childFH);
