@@ -1,8 +1,7 @@
-#ifndef RECENTDOCUMENTNOTIFIER_H
-#define RECENTDOCUMENTNOTIFIER_H
+#ifndef RECENTDOCUMENTSNOTIFIER_H
+#define RECENTDOCUMENTSNOTIFIER_H
 
 #include <KDEDModule>
-#include <QtDBus/QtDBus>
 
 class KDirWatch;
 
