@@ -26,7 +26,6 @@
 #include "kio_sftp_trace_debug.h"
 #include <cerrno>
 #include <cstring>
-#include <utime.h>
 
 #include <QCoreApplication>
 #include <QDir>
@@ -34,6 +33,7 @@
 #include <QVarLengthArray>
 #include <QMimeType>
 #include <QMimeDatabase>
+#include <QDateTime>
 
 #include <kuser.h>
 #include <kmessagebox.h>
@@ -42,6 +42,14 @@
 #include <kconfiggroup.h>
 #include <kio/ioslave_defaults.h>
 
+#ifdef Q_OS_WIN
+#include <experimental/filesystem>  // for permissions
+using namespace std::experimental::filesystem;
+#include <qplatformdefs.h>
+#else
+#include <utime.h>
+#endif
+
 #define KIO_SFTP_SPECIAL_TIMEOUT 30
 
 // How big should each data packet be? Definitely not bigger than 64kb or
@@ -344,7 +352,7 @@ bool sftpProtocol::createUDSEntry(const QString &filename, const QByteArray &pat
     mode_t access;
     char *link;
     bool isBrokenLink = false;
-    long long fileType = S_IFREG;
+    long long fileType = QT_STAT_REG;
     long long size = 0LL;
 
     Q_ASSERT(entry.count() == 0);
@@ -378,23 +386,27 @@ bool sftpProtocol::createUDSEntry(const QString &filename, const QByteArray &pat
 
     if (isBrokenLink) {
         // It is a link pointing to nowhere
-        fileType = S_IFMT - 1;
+        fileType = QT_STAT_MASK - 1;
+#ifdef Q_OS_WIN
+        access = static_cast<mode_t>(perms::owner_all | perms::group_all | perms::others_all);
+#else
         access = S_IRWXU | S_IRWXG | S_IRWXO;
+#endif
         size = 0LL;
     } else {
         switch (sb->type) {
         case SSH_FILEXFER_TYPE_REGULAR:
-            fileType = S_IFREG;
+            fileType = QT_STAT_REG;
             break;
         case SSH_FILEXFER_TYPE_DIRECTORY:
-            fileType = S_IFDIR;
+            fileType = QT_STAT_DIR;
             break;
         case SSH_FILEXFER_TYPE_SYMLINK:
-            fileType = S_IFLNK;
+            fileType = QT_STAT_LNK;
             break;
         case SSH_FILEXFER_TYPE_SPECIAL:
         case SSH_FILEXFER_TYPE_UNKNOWN:
-            fileType = S_IFMT - 1;
+            fileType = QT_STAT_MASK - 1;
             break;
         }
         access = sb->permissions & 07777;
@@ -1747,7 +1759,11 @@ sftpProtocol::StatusCode sftpProtocol::sftpPut(const QUrl& url, int permissions,
                     mode_t initialMode;
 
                     if (permissions != -1) {
+#ifdef Q_OS_WIN
+                        initialMode = permissions | static_cast<mode_t>(perms::owner_write | perms::owner_read);
+#else
                         initialMode = permissions | S_IWUSR | S_IRUSR;
+#endif
                     } else {
                         initialMode = 0644;
                     }
@@ -1918,11 +1934,10 @@ sftpProtocol::StatusCode sftpProtocol::sftpCopyGet(const QUrl& url, const QStrin
     qCDebug(KIO_SFTP_LOG) << url << "->" << sCopyFile << ", permissions=" << permissions;
 
     // check if destination is ok ...
-    QT_STATBUF buff;
-    const bool bDestExists = (QT_STAT(QFile::encodeName(sCopyFile), &buff) != -1);
-
+    QFileInfo copyFile(sCopyFile);
+    const bool bDestExists = copyFile.exists();
     if(bDestExists)  {
-        if(S_ISDIR(buff.st_mode)) {
+        if(copyFile.isDir()) {
             errorCode = ERR_IS_DIRECTORY;
             return sftpProtocol::ClientError;
         }
@@ -1935,16 +1950,17 @@ sftpProtocol::StatusCode sftpProtocol::sftpCopyGet(const QUrl& url, const QStrin
 
     bool bResume = false;
     const QString sPart = sCopyFile + QLatin1String(".part"); // do we have a ".part" file?
-    const bool bPartExists = (QT_STAT(QFile::encodeName(sPart), &buff) != -1);
+    QFileInfo partFile(sPart);
+    const bool bPartExists = partFile.exists();
     const bool bMarkPartial = config()->readEntry("MarkPartial", true);
     const QString dest = (bMarkPartial ? sPart : sCopyFile);
 
-    if (bMarkPartial && bPartExists && buff.st_size > 0) {
-        if (S_ISDIR(buff.st_mode)) {
+    if (bMarkPartial && bPartExists && copyFile.size() > 0) {
+        if(partFile.isDir()) {
             errorCode = ERR_DIR_ALREADY_EXIST;
             return sftpProtocol::ClientError;                            // client side error
         }
-        bResume = canResume( buff.st_size );
+        bResume = canResume( copyFile.size() );
     }
 
     if (bPartExists && !bResume)                  // get rid of an unwanted ".part" file
@@ -1954,7 +1970,11 @@ sftpProtocol::StatusCode sftpProtocol::sftpCopyGet(const QUrl& url, const QStrin
     // otherwise we can be in for a surprise on NFS.
     mode_t initialMode;
     if (permissions != -1)
+#ifdef Q_OS_WIN
+        initialMode = permissions | static_cast<mode_t>(perms::owner_write);
+#else
         initialMode = permissions | S_IWUSR;
+#endif
     else
         initialMode = 0666;
 
@@ -2000,10 +2020,12 @@ sftpProtocol::StatusCode sftpProtocol::sftpCopyGet(const QUrl& url, const QStrin
                 }
             }
         }
-        else if (QT_STAT( QFile::encodeName(sPart), &buff ) == 0) { // should a very small ".part" be deleted?
+        else{
+            partFile.refresh();
             const int size = config()->readEntry("MinimumKeepSize", DEFAULT_MINIMUM_KEEP_SIZE);
-            if (buff.st_size <  size)
+            if (partFile.exists() && partFile.size() <  size) { // should a very small ".part" be deleted?
                 QFile::remove(sPart);
+            }
         }
     }
 
@@ -2011,10 +2033,15 @@ sftpProtocol::StatusCode sftpProtocol::sftpCopyGet(const QUrl& url, const QStrin
     if (!mtimeStr.isEmpty()) {
         QDateTime dt = QDateTime::fromString(mtimeStr, Qt::ISODate);
         if (dt.isValid()) {
-            struct utimbuf utbuf;
-            utbuf.actime = buff.st_atime; // access time, unchanged
-            utbuf.modtime = dt.toTime_t(); // modification time
-            utime(QFile::encodeName(sCopyFile), &utbuf);
+            QFile receivedFile(sCopyFile);
+            if (receivedFile.exists()) {
+                if (!receivedFile.open(QIODevice::ReadWrite | QIODevice::Text)) {
+                    QString error_msg = receivedFile.errorString();
+                    qCDebug(KIO_SFTP_LOG) << "Couldn't update modified time : " << error_msg;
+                } else {
+                    receivedFile.setFileTime(dt, QFileDevice::FileModificationTime);
+                }
+            }
         }
     }
 
@@ -2026,11 +2053,10 @@ sftpProtocol::StatusCode sftpProtocol::sftpCopyPut(const QUrl& url, const QStrin
     qCDebug(KIO_SFTP_LOG) << sCopyFile << "->" << url << ", permissions=" << permissions << ", flags" << flags;
 
     // check if source is ok ...
-    QT_STATBUF buff;
-    bool bSrcExists = (QT_STAT(QFile::encodeName(sCopyFile), &buff) != -1);
-
+    QFileInfo copyFile(sCopyFile);
+    bool bSrcExists = copyFile.exists();
     if (bSrcExists) {
-        if (S_ISDIR(buff.st_mode)) {
+        if(copyFile.isDir()) {
             errorCode = ERR_IS_DIRECTORY;
             return sftpProtocol::ClientError;
         }
@@ -2046,7 +2072,7 @@ sftpProtocol::StatusCode sftpProtocol::sftpCopyPut(const QUrl& url, const QStrin
         return sftpProtocol::ClientError;
     }
 
-    totalSize(buff.st_size);
+    totalSize(copyFile.size());
 
     // delegate the real work (errorCode gets status) ...
     StatusCode ret = sftpPut(url, permissions, flags, errorCode, fd);
@@ -2169,7 +2195,7 @@ void sftpProtocol::listDir(const QUrl& url) {
         mode_t access;
         char *link;
         bool isBrokenLink = false;
-        long long fileType = S_IFREG;
+        long long fileType = QT_STAT_REG;
         long long size = 0LL;
 
         dirent = sftp_readdir(mSftp, dp);
@@ -2205,19 +2231,23 @@ void sftpProtocol::listDir(const QUrl& url) {
 
         if (isBrokenLink) {
             // It is a link pointing to nowhere
-            fileType = S_IFMT - 1;
+            fileType = QT_STAT_MASK - 1;
+#ifdef Q_OS_WIN
+            access = static_cast<mode_t>(perms::owner_all | perms::group_all | perms::others_all);
+#else
             access = S_IRWXU | S_IRWXG | S_IRWXO;
+#endif
             size = 0LL;
         } else {
             switch (dirent->type) {
             case SSH_FILEXFER_TYPE_REGULAR:
-                fileType = S_IFREG;
+                fileType = QT_STAT_REG;
                 break;
             case SSH_FILEXFER_TYPE_DIRECTORY:
-                fileType = S_IFDIR;
+                fileType = QT_STAT_DIR;
                 break;
             case SSH_FILEXFER_TYPE_SYMLINK:
-                fileType = S_IFLNK;
+                fileType = QT_STAT_LNK;
                 break;
             case SSH_FILEXFER_TYPE_SPECIAL:
             case SSH_FILEXFER_TYPE_UNKNOWN:
@@ -2439,7 +2469,8 @@ sftpProtocol::GetRequest::GetRequest(sftp_file file, sftp_attributes sb, ushort
 
 }
 
-bool sftpProtocol::GetRequest::enqueueChunks() {
+bool sftpProtocol::GetRequest::enqueueChunks()
+{
     sftpProtocol::GetRequest::Request request;
 
     qCDebug(KIO_SFTP_TRACE_LOG) << "enqueueChunks";
